#!/bin/bash

set -e

CMD="$@"

JFMC_VERSION="1.9"
DOCKER_SERVER_CURRENT_VER=$(docker version --format '{{.Server.Version}}') || DOCKER_SERVER_CURRENT_VER=""

# Mission Control installer workdir
JFMC_DIR="${HOME}/.jfrog/jfmc/jfmc-installer"

# Mission Control installer conf file, should be created in the first run
JFMC_CONF="${JFMC_DIR}/jfmc-env.conf"

JFMC_MOUNT_ROOT_DEFAULT="${HOME}/.jfrog/jfmc"

JFMC_PORT="8080"

[ ! -d "$JFMC_DIR" ] && mkdir -p "$JFMC_DIR"

# Create the installer configuration file
if [ ! -f "$JFMC_CONF" ]; then
    echo -e "\nJFMC_MOUNT_ROOT must be set on jfmc first installation \nPlease type desired JFMC_MOUNT_ROOT location"

    read -p "Enter mount root [${JFMC_MOUNT_ROOT_DEFAULT}]: " JFMC_MOUNT_ROOT
    JFMC_MOUNT_ROOT=${JFMC_MOUNT_ROOT:-${JFMC_MOUNT_ROOT_DEFAULT}}
    # Write to conf file
    echo "export JFMC_MOUNT_ROOT=${JFMC_MOUNT_ROOT}" >> ${JFMC_CONF}
    echo "JFMC_MOUNT_ROOT is now specified in ${JFMC_CONF}, as ${JFMC_MOUNT_ROOT}"
fi

# Load the installer configuration file
if [ -f "$JFMC_CONF" ]; then
    source "${JFMC_CONF}"
else
    echo "ERROR: configuration file does not exist [${JFMC_CONF}]"
    exit 1
fi

if [ -z ${JFMC_MOUNT_ROOT} ]
then
    echo "ERROR: JFMC_MOUNT_ROOT is not set, please update the conf file [${JFMC_CONF}]"
    exit 1
fi
echo "INFO: Using JFMC_MOUNT_ROOT=${JFMC_MOUNT_ROOT}"

ETC_FILE=${JFMC_MOUNT_ROOT}/etc/mission-control.properties

# Pass an overwritten port
if [ -f ${ETC_FILE} ]; then
    grep "^server.port" ${ETC_FILE}
    if [ $? -eq 0 ]; then
        JFMC_PORT=$(grep  "^server.port" ${ETC_FILE} | awk -F'=' '{print $2}')
    fi
fi

# Setup options for connecting to docker host
if [ -z "$DOCKER_HOST" ]; then
    DOCKER_HOST="/var/run/docker.sock"
fi
if [ -S "$DOCKER_HOST" ]; then
    DOCKER_ADDR="-v $DOCKER_HOST:$DOCKER_HOST -e DOCKER_HOST"
else
    DOCKER_ADDR="-e DOCKER_HOST -e DOCKER_TLS_VERIFY -e DOCKER_CERT_PATH"
fi

# Only allocate tty if we detect one
if [ -t 1 ]; then
    DOCKER_RUN_OPTIONS="-t"
fi
if [ -t 0 ]; then
    DOCKER_RUN_OPTIONS="$DOCKER_RUN_OPTIONS -i"
fi

JFMC_VOLUMES="-v ${JFMC_MOUNT_ROOT}/jfmc-installer:/data -v ${JFMC_MOUNT_ROOT}:/jfmc_global_mount_root"

JFMC_DOCKER_REPO="docker.bintray.io/jfrog"

IMAGE="${JFMC_DOCKER_REPO}/jfmc-installer:$JFMC_VERSION"

[ "${JFMC_PORT}" != "8080" ] && echo "INFO: Using none default http port: ${JFMC_PORT}"

exec docker run --rm $DOCKER_RUN_OPTIONS $DOCKER_ADDR $JFMC_VOLUMES -e JFMC_PORT=$JFMC_PORT -e JFMC_DOCKER_REPO=$JFMC_DOCKER_REPO -e JFMC_VERSION=$JFMC_VERSION -e JFMC_MOUNT_ROOT=$JFMC_MOUNT_ROOT -e DOCKER_SERVER_CURRENT_VER=$DOCKER_SERVER_CURRENT_VER $IMAGE "$CMD"

exit $?